Snapshot Test Results

Snapshot Tests

## {{ name }}

{{ path }}:{{ line }}

##### Result

##### Expected

{{ result }}
{{ expected }}

#### Details:

Results Values

## Result

{{ path }}:{{ line }}
{{ result }}

## Expected

{{ expectedPath }}
{{ expected }}

## Difference

Result - Expected
{{ expected }}
{{ result }}
{{ table }}

#### Help

How are snapshots created?
Snapshot files are created by default with the following format:
`<parent folder of test>/snapshots/<name of test>.svg`
This can be overridden by using the `compare_to` argument when calling the `compare_snapshots` fixture. If a test is renamed/moved, the original snapshot must be moved manually, or `--txtology-snap-update` can be used with pytest to recreate.
What pytest options are available?
`--txtology-snap-report`

Path to store the final HTML report with snapshot test results.

`--txtology-snap-root`

Path to store snapshot testing files, such as reports and pytest shared worker results.

`--txtology-snap-template`

Custom template to use for the HTML report with snapshot test results.

`--txtology-snap-update`

Update snapshot files to the new test results if they do not match.

For more information on available arguments, run:
`pytest --help`